@@ -5,15 +5,15 @@ use strict;
 
 =head1 NAME
 
-File::Assets - Manage .css and .js assets in a web application
+File::Assets - Manage .css and .js assets for a web page or application
 
 =head1 VERSION
 
-Version 0.060_7
+Version 0.064_1
 
 =cut
 
-our $VERSION = '0.060_7';
+our $VERSION = '0.064_1';
 
 =head1 SYNOPSIS
 
@@ -21,20 +21,29 @@ our $VERSION = '0.060_7';
 
     my $assets = File::Assets->new( base => [ $uri_root, $dir_root ] )
 
-    $assets->set_output_path("built/") # Put minified files in $dir_root/built/... (the trailing slash is important)
+    # Put minified files in $dir_root/built/... (the trailing slash is important)
+    $assets->set_output_path("built/")
 
-    $assets->include("/static/style.css") # File::Assets will automatically detect the type based on the extension
-
-    # Then, later ...
-    
-    $assets->include("/static/main.js")
-    $assets->include("/static/style.css") # This asset won't get included twice, as File::Assets will ignore repeats of a path
+    # File::Assets will automatically detect the type based on the extension
+    $assets->include("/static/style.css")
 
     # You can also include external assets:
-
     $assets->include("http://ajax.googleapis.com/ajax/libs/jquery/1.2.6/jquery.min.js");
-    
-    # And then, in your .tt (Template Toolkit) files:
+
+    # This asset won't get included twice, as File::Assets will ignore repeats of a path
+    $assets->include("/static/style.css")
+
+    # And finally ...
+    $assets->export
+
+    # Or you can iterate (in order)
+    for my $asset ($assets->exports) {
+        
+        print $asset->uri, "\n";
+
+    }
+
+In your .tt (Template Toolkit) files:
 
     [% WRAPPER page.tt %]
 
@@ -68,13 +77,6 @@ our $VERSION = '0.060_7';
 
     </html>
 
-    # If you want to process each asset individually, you can use exports:
-
-    for my $asset ($assets->exports) {
-
-        print $asset->uri, "\n";
-    }
-
 Use the minify option to perform minification before export
 
     my $assets = File::Assets->new( minify => 1, ... )
@@ -130,6 +132,10 @@ If you want to use the YUI Compressor, you should have version 2.2.5 or above.
 
 YUI Compressor 2.1.1 (and below) will *NOT WORK*
 
+To use the compressor for minification specify the path to the .jar like so:
+
+    my $assets = File::Assets->new( minify => "/path/to/yuicompressor.jar", ... )
+
 =head2 Specifying an C<output_path> pattern
 
 When aggregating or minifying assets, you need to put the result in a new file. 
@@ -158,9 +164,10 @@ A pattern of C<%n%-l.%e> can result in the following:
 
 If the pattern ends with a "/", then the default pattern will be appended
 
+    xyzzy/          => xyzzy/%n%-l-%f.%e
+
 If the pattern does not have an extension-like ending, then "%.e" will be appended
 
-    xyzzy/          => xyzzy/%n%-l-%f.%e
     xyzzy           => xyzzy.%e
 
 =head2 Strange output or "sticky" content
@@ -184,6 +191,7 @@ use Tie::LLHash;
 use Path::Resource;
 use Scalar::Util qw/blessed refaddr/;
 use HTML::Declare qw/LINK SCRIPT STYLE/;
+use File::Copy();
 
 use File::Assets::Asset;
 use File::Assets::Cache;
@@ -196,28 +204,28 @@ Create and return a new File::Assets object.
 
 You can configure the object with the following:
     
-    base            # A hash reference with a C<uri> key/value and a C<dir> key/value.
+    base            # A hash reference with a "uri" key/value and a "dir" key/value.
                       For example: { uri => http://example.com/assets, dir => /var/www/htdocs/assets }
     
-                    # A L<URI::ToDisk> object
+                    # A URI::ToDisk object
 
-                    # A L<Path::Resource> object
+                    # A Path::Resource object
 
-    minify          # "1" or "best" - Will either use L<JavaScript::Minifier::XS> & L<CSS::Minifier::XS> or
-                                      L<JavaScript::Minifier> & L<CSS::Minifier> (depending on availability)
+    minify          # "1" or "best" - Will either use JavaScript::Minifier::XS> & CSS::Minifier::XS or
+                                      JavaScript::Minifier> & CSS::Minifier (depending on availability)
                                       for minification
 
                     # "0" or "" or undef - Don't do any minfication (this is the default)
 
                     # "./path/to/yuicompressor.jar" - Will use YUI Compressor via the given .jar for minification
 
-                    # "minifier" - Will use L<JavaScript::Minifier> & L<CSS::Minifier> for minification
+                    # "minifier" - Will use JavaScript::Minifier & CSS::Minifier for minification
 
-                    # "xs" or "minifier-xs" - Will use L<JavaScript::Minifier::XS> & L<CSS::Minifier::XS> for minification
+                    # "xs" or "minifier-xs" - Will use JavaScript::Minifier::XS & CSS::Minifier::XS for minification
 
     output_path     # Designates the output path for minified .css and .js assets
-                      The default output path pattern is C<%n%-l%-d.%e> (rooted at the dir of <base>)
-                      See above in "Specifying an C<output_path> pattern" for details
+                      The default output path pattern is "%n%-l%-d.%e" (rooted at the dir of <base>)
+                      See above in "Specifying an output_path pattern" for details
 
 =cut
 
@@ -255,7 +263,7 @@ sub new {
 
     if (my $minify = $_{minify}) {
         if      ($minify eq 1 || $minify =~ m/^\s*(?:minifier-)?best\s*$/i)  { $self->filter("minifier-best") }
-        elsif   ($minify =~ m/^\s*yuicompressor:/)                           { $self->filter($minify) }
+        elsif   ($minify =~ m/^\s*yui-?compressor:/)                         { $self->filter($minify) }
         elsif   ($minify =~ m/\.jar/i)                                       { $self->filter("yuicompressor:$minify") }
         elsif   ($minify =~ m/^\s*(?:minifier-)?xs\s*$/i)                    { $self->filter("minifier-xs") }
         elsif   ($minify =~ m/^\s*minifier\s*$/i)                            { $self->filter("minifier") }
@@ -298,8 +306,8 @@ The hash reference should contain the follwing information:
 
     type        # Optional if a path is given, required for content
     rank        # Optional, 0 by default (Less than zero is earlier, greater than zero is later)
-    base        # Optional, by default the base of $assets
     inline      # Optional, by default true if content was given, false is a path was given
+    base        # Optional, by default the base of $assets
 
 You can also pass extra information through the hash. Any extra information will be bundled in the ->attributes hash of $asset.
 For example, you can control the media type of a text/css asset by doing something like:
@@ -579,14 +587,23 @@ sub kind {
 sub _exports {
     my $self = shift;
     my $type = shift;
-    $type = File::Assets::Util->parse_type($type);
+
+    my $image_export;
+    $image_export = 1 if $type && $type =~ m/^image(?:\/\*)?$/;
+
     my $hash = $self->_registry_hash;
     my @assets; 
-    if (defined $type) {
-        @assets = grep { $type->type eq $_->type->type } values %$hash;
+    if ($image_export) {
+        @assets = grep { "image" eq $_->type->mediaType } values %$hash;
     }
     else {
-        @assets = values %$hash;
+        $type = File::Assets::Util->parse_type($type) unless $image_export;
+        if (defined $type) {
+            @assets = grep { $type->type eq $_->type->type } values %$hash;
+        }
+        else {
+            @assets = values %$hash;
+        }
     }
 
     my %bucket;
@@ -596,26 +613,79 @@ sub _exports {
         $bucket->add_asset($asset);
     }
 
-    my $filter_scheme = $self->{filter_scheme};
-    my @global = @{ $filter_scheme->{'*'} || [] };
     my @bucket;
-    for my $kind (sort keys %bucket) {
-        push @bucket, my $bucket = $bucket{$kind};
-        $bucket->add_filter($_) for @global;
-        my $head = $bucket->kind->head;
-        for my $category (sort grep { ! m/^$head-/ } keys %$filter_scheme) {
-            next if length $category > length $kind; # Too specific
-            next unless 0 == index $kind, $category;
-            $bucket->add_filter($_) for (@{ $filter_scheme->{$category} });
+    if ($image_export) {
+        @bucket = values %bucket;
+    }
+    else {
+        my $filter_scheme = $self->{filter_scheme};
+        my @global = @{ $filter_scheme->{'*'} || [] };
+        for my $kind (sort keys %bucket) {
+            push @bucket, my $bucket = $bucket{$kind};
+            $bucket->add_filter($_) for @global;
+            my $head = $bucket->kind->head;
+            for my $category (sort grep { ! m/^$head-/ } keys %$filter_scheme) {
+                next if length $category > length $kind; # Too specific
+                next unless 0 == index $kind, $category;
+                $bucket->add_filter($_) for (@{ $filter_scheme->{$category} });
+            }
         }
     }
 
-    return map { $_->exports } @bucket;
+    my @exports;
+    for my $bucket (@bucket) {
+        my $kind = $bucket->kind;
+        if ($kind->type->mediaType eq "image") {
+            for my $asset ($bucket->exports) {
+                $self->_transfer_asset($asset, $kind);
+            }
+        }
+        else {
+            push @exports, $bucket->exports;
+        }
+    }
+
+    if (! $image_export && $type && $type->type eq "text/css") {
+        $self->_exports("image"); # Do an image export if we're explicitly exporting css
+    }
+
+    return @exports;
+}
+
+sub _transfer_asset {
+    my $self = shift;
+    my $asset = shift;
+    my $kind = shift;
+
+    # This method makes the following assumption:
+    # $self->{output_path_scheme} = [ [ qw/*/ => $scheme ] ]
+
+    my $output_path_scheme = $self->{output_path_scheme}->[0]->[1];
+    my $output_path = File::Assets::Util->build_output_path($output_path_scheme, {
+        name => $asset->path->last,
+    @_ });
+
+    my $output_file = $self->rsc->file($output_path);
+    my $asset_path = $asset->path;
+    my $asset_file = $asset->file;
+
+    croak "Asset $asset_path does not exist!" unless -e $asset_file;
+
+    if (! -e $output_file || $asset_file->stat->mtime > $output_file->stat->mtime) {
+        my $dir = $output_file->parent;
+        $dir->mkpath unless -d $dir;
+        if ($dir->stat->dev eq $asset_file->stat->dev) {
+            link $asset_file, $output_file or croak "Couldn't link $asset_file, $output_file: $!";
+        }
+        else {
+            File::Copy::copy $asset_file, $output_file or croak "Couldn't copy $asset_file, $output_file: $!";
+        }
+    }
 }
 
 =head2 $assets->set_name( <name> )
 
-Set the "name" of $assets
+Set the name of $assets
 
 This is exactly the same as
 
@@ -632,12 +702,12 @@ Set the base uri, dir, and path for assets
 
     { uri => ..., dir => ..., path => ... }
 
-Given a dir of "/var/www/htdocs", a uri of "http://example.com/static", and a
-path of "assets" then:
+Given a dir of C</var/www/htdocs>, a uri of C<http://example.com/static>, and a
+path of C<assets> then:
 
     $assets will look for files in "/var/www/htdocs/assets"
 
-    $assets will "serve" files with "http://example.com/statis/assets"
+    $assets will "serve" files with "http://example.com/static/assets"
 
 =cut
 
@@ -894,6 +964,14 @@ L<JS::YUI::Loader>
 
 L<JS::jQuery::Loader>
 
+=head1 SOURCE
+
+You can contribute or fork this project via GitHub:
+
+L<http://github.com/robertkrimen/file-assets/tree/master>
+
+    git clone git://github.com/robertkrimen/file-assets.git File-Assets
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-file-assets at rt.cpan.org>, or through
